# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_brand_history_list_response import OrganizationsBrandHistoryListResponse

class TestOrganizationsBrandHistoryListResponse(unittest.TestCase):
    """OrganizationsBrandHistoryListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsBrandHistoryListResponse:
        """Test OrganizationsBrandHistoryListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsBrandHistoryListResponse`
        """
        model = OrganizationsBrandHistoryListResponse()
        if include_optional:
            return OrganizationsBrandHistoryListResponse(
                current_page = 56,
                error = '',
                history = [
                    neurograph.v1.models.organizations/brand_history_item.organizations.BrandHistoryItem(
                        accessibility_level = '', 
                        background_img_url = '', 
                        change_reason = '', 
                        changed_by = '', 
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        component_config = [
                            56
                            ], 
                        created_at = '', 
                        dark_mode_enabled = True, 
                        generation_metadata = [
                            56
                            ], 
                        is_ai_generated = True, 
                        logo_img_url = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        spacing_config = [
                            56
                            ], 
                        tertiary_color = '', 
                        typography_config = [
                            56
                            ], 
                        version = 56, )
                    ],
                items_per_page = 56,
                total_count = 56
            )
        else:
            return OrganizationsBrandHistoryListResponse(
        )
        """

    def testOrganizationsBrandHistoryListResponse(self):
        """Test OrganizationsBrandHistoryListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
